# Copyright 2001-2005 The Apache Software Foundation
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
package APR::Const;

use ModPerl::Const ();
use APR ();
use XSLoader ();

our $VERSION = '0.009000';
our @ISA = qw(ModPerl::Const);

XSLoader::load(__PACKAGE__, $VERSION);

1;

=head1 NAME

APR::Const - Perl Interface for APR Constants






=head1 Synopsis

  # make the constants available but don't import them
  use APR::Const -compile => qw(constant names ...);
  
  # w/o the => syntax sugar
  use APR::Const ("-compile", qw(constant names ...));
  
  # compile and import the constants
  use APR::Const qw(constant names ...);







=head1 Description

This package contains constants specific to C<APR> features.

Refer to C<L<the Apache::Const description
section|docs::2.0::api::Apache::Const/Description>> for more
information.







=head1 Constants



=head2 C<:common>

  use APR::Const -compile => qw(:common);

The C<:common> group is for XXX constants.




=head3 C<APR::SUCCESS>

=over

=item since: 1.99_12

=back





=head2 C<:error>

  use APR::Const -compile => qw(:error);

The C<:error> group is for XXX constants.




=head3 C<APR::EABOVEROOT>

=over

=item since: 1.99_12

=back





=head3 C<APR::EABSOLUTE>

=over

=item since: 1.99_12

=back





=head3 C<APR::EACCES>

=over

=item since: 1.99_12

=back





=head3 C<APR::EAGAIN>

=over

=item since: 1.99_12

=back

The error I<Resource temporarily unavailable>, may be returned by many
different system calls, especially IO calls.



=head3 C<APR::EBADDATE>

=over

=item since: 1.99_12

=back





=head3 C<APR::EBADF>

=over

=item since: 1.99_12

=back





=head3 C<APR::EBADIP>

=over

=item since: 1.99_12

=back





=head3 C<APR::EBADMASK>

=over

=item since: 1.99_12

=back





=head3 C<APR::EBADPATH>

=over

=item since: 1.99_12

=back





=head3 C<APR::EBUSY>

=over

=item since: 1.99_12

=back





=head3 C<APR::ECONNABORTED>

=over

=item since: 1.99_12

=back





=head3 C<APR::ECONNREFUSED>

=over

=item since: 1.99_12

=back





=head3 C<APR::ECONNRESET>

=over

=item since: 1.99_12

=back





=head3 C<APR::EDSOOPEN>

=over

=item since: 1.99_12

=back





=head3 C<APR::EEXIST>

=over

=item since: 1.99_12

=back





=head3 C<APR::EFTYPE>

=over

=item since: 1.99_12

=back





=head3 C<APR::EGENERAL>

=over

=item since: 1.99_12

=back





=head3 C<APR::EHOSTUNREACH>

=over

=item since: 1.99_12

=back





=head3 C<APR::EINCOMPLETE>

=over

=item since: 1.99_12

=back





=head3 C<APR::EINIT>

=over

=item since: 1.99_12

=back





=head3 C<APR::EINPROGRESS>

=over

=item since: 1.99_12

=back





=head3 C<APR::EINTR>

=over

=item since: 1.99_12

=back





=head3 C<APR::EINVAL>

=over

=item since: 1.99_12

=back





=head3 C<APR::EINVALSOCK>

=over

=item since: 1.99_12

=back





=head3 C<APR::EMFILE>

=over

=item since: 1.99_12

=back





=head3 C<APR::EMISMATCH>

=over

=item since: 1.99_12

=back





=head3 C<APR::ENAMETOOLONG>

=over

=item since: 1.99_12

=back





=head3 C<APR::END>

=over

=item since: 1.99_12

=back





=head3 C<APR::ENETUNREACH>

=over

=item since: 1.99_12

=back





=head3 C<APR::ENFILE>

=over

=item since: 1.99_12

=back





=head3 C<APR::ENODIR>

=over

=item since: 1.99_12

=back





=head3 C<APR::ENOENT>

=over

=item since: 1.99_12

=back





=head3 C<APR::ENOLOCK>

=over

=item since: 1.99_12

=back





=head3 C<APR::ENOMEM>

=over

=item since: 1.99_12

=back





=head3 C<APR::ENOPOLL>

=over

=item since: 1.99_12

=back





=head3 C<APR::ENOPOOL>

=over

=item since: 1.99_12

=back





=head3 C<APR::ENOPROC>

=over

=item since: 1.99_12

=back





=head3 C<APR::ENOSHMAVAIL>

=over

=item since: 1.99_12

=back





=head3 C<APR::ENOSOCKET>

=over

=item since: 1.99_12

=back





=head3 C<APR::ENOSPC>

=over

=item since: 1.99_12

=back





=head3 C<APR::ENOSTAT>

=over

=item since: 1.99_12

=back





=head3 C<APR::ENOTDIR>

=over

=item since: 1.99_12

=back





=head3 C<APR::ENOTEMPTY>

=over

=item since: 1.99_12

=back





=head3 C<APR::ENOTHDKEY>

=over

=item since: 1.99_12

=back





=head3 C<APR::ENOTHREAD>

=over

=item since: 1.99_12

=back





=head3 C<APR::ENOTIME>

=over

=item since: 1.99_12

=back





=head3 C<APR::ENOTIMPL>

Something is not implemented

=over

=item since: 1.99_12

=back





=head3 C<APR::ENOTSOCK>

=over

=item since: 1.99_12

=back





=head3 C<APR::EOF>

=over

=item since: 1.99_12

=back





=head3 C<APR::EPATHWILD>

=over

=item since: 1.99_12

=back





=head3 C<APR::EPIPE>

=over

=item since: 1.99_12

=back





=head3 C<APR::EPROC_UNKNOWN>

=over

=item since: 1.99_12

=back





=head3 C<APR::ERELATIVE>

=over

=item since: 1.99_12

=back





=head3 C<APR::ESPIPE>

=over

=item since: 1.99_12

=back





=head3 C<APR::ESYMNOTFOUND>

=over

=item since: 1.99_12

=back





=head3 C<APR::ETIMEDOUT>

=over

=item since: 1.99_12

=back





=head3 C<APR::EXDEV>

=over

=item since: 1.99_12

=back





=head2 C<:fopen>

  use APR::Const -compile => qw(:fopen);

The C<:fopen> group is for XXX constants.




=head3 C<APR::FOPEN_BINARY>

=over

=item since: 1.99_12

=back





=head3 C<APR::FOPEN_BUFFERED>

=over

=item since: 1.99_12

=back





=head3 C<APR::FOPEN_CREATE>

=over

=item since: 1.99_12

=back





=head3 C<APR::FOPEN_DELONCLOSE>

=over

=item since: 1.99_12

=back





=head3 C<APR::FOPEN_EXCL>

=over

=item since: 1.99_12

=back





=head3 C<APR::FOPEN_PEND>

=over

=item since: 1.99_12

=back





=head3 C<APR::FOPEN_READ>

=over

=item since: 1.99_12

=back





=head3 C<APR::FOPEN_TRUNCATE>

=over

=item since: 1.99_12

=back





=head3 C<APR::FOPEN_WRITE>

=over

=item since: 1.99_12

=back





=head2 C<:filepath>

  use APR::Const -compile => qw(:filepath);

The C<:filepath> group is for XXX constants.





=head3 C<APR::FILEPATH_ENCODING_LOCALE>

=over

=item since: 1.99_12

=back





=head3 C<APR::FILEPATH_ENCODING_UNKNOWN>

=over

=item since: 1.99_12

=back





=head3 C<APR::FILEPATH_ENCODING_UTF8>

=over

=item since: 1.99_12

=back





=head3 C<APR::FILEPATH_NATIVE>

=over

=item since: 1.99_12

=back





=head3 C<APR::FILEPATH_NOTABOVEROOT>

=over

=item since: 1.99_12

=back





=head3 C<APR::FILEPATH_NOTABSOLUTE>

=over

=item since: 1.99_12

=back





=head3 C<APR::FILEPATH_NOTRELATIVE>

=over

=item since: 1.99_12

=back





=head3 C<APR::FILEPATH_SECUREROOT>

=over

=item since: 1.99_12

=back





=head3 C<APR::FILEPATH_SECUREROOTTEST>

=over

=item since: 1.99_12

=back





=head3 C<APR::FILEPATH_TRUENAME>

=over

=item since: 1.99_12

=back





=head2 C<:fprot>

  use APR::Const -compile => qw(:fprot);

The C<:fprot> group is used by
C<L<$finfo-E<gt>protection|docs::2.0::api::APR::Finfo/C_protection_>>.




=head3 C<APR::FPROT_GEXECUTE>

Execute by group

=over

=item since: 1.99_17

=back






=head3 C<APR::FPROT_GREAD>

Read by group

=over

=item since: 1.99_17

=back




=head3 C<APR::FPROT_GSETID>

Set group id

=over

=item since: 1.99_17

=back




=head3 C<APR::FPROT_GWRITE>

Write by group

=over

=item since: 1.99_17

=back




=head3 C<APR::FPROT_OS_DEFAULT>

use OS's default permissions

=over

=item since: 1.99_17

=back




=head3 C<APR::FPROT_UEXECUTE>

Execute by user

=over

=item since: 1.99_17

=back




=head3 C<APR::FPROT_UREAD>

Read by user

=over

=item since: 1.99_17

=back




=head3 C<APR::FPROT_USETID>

Set user id

=over

=item since: 1.99_17

=back




=head3 C<APR::FPROT_UWRITE>

Write by user

=over

=item since: 1.99_17

=back




=head3 C<APR::FPROT_WEXECUTE>

Execute by others

=over

=item since: 1.99_17

=back




=head3 C<APR::FPROT_WREAD>

Read by others

=over

=item since: 1.99_17

=back




=head3 C<APR::FPROT_WSTICKY>

Sticky bit

=over

=item since: 1.99_17

=back




=head3 C<APR::FPROT_WWRITE>

Write by others

=over

=item since: 1.99_17

=back










=head2 C<:filetype>

  use APR::Const -compile => qw(:filetype);

The C<:filetype> group is used by
C<L<$finfo-E<gt>filetype|docs::2.0::api::APR::Finfo/C_filetype_>>.




=head3 C<APR::FILETYPE_BLK>

a file is a block device

=over

=item since: 1.99_17

=back






=head3 C<APR::FILETYPE_CHR>

a file is a character device

=over

=item since: 1.99_17

=back





=head3 C<APR::FILETYPE_DIR>

a file is a directory

=over

=item since: 1.99_17

=back





=head3 C<APR::FILETYPE_LNK>

a file is a symbolic link

=over

=item since: 1.99_17

=back





=head3 C<APR::FILETYPE_NOFILE>

the file type is undedetermined.

=over

=item since: 1.99_17

=back





=head3 C<APR::FILETYPE_PIPE>

a file is a FIFO or a pipe.

=over

=item since: 1.99_17

=back





=head3 C<APR::FILETYPE_REG>

a file is a regular file.

=over

=item since: 1.99_17

=back





=head3 C<APR::FILETYPE_SOCK>

a file is a [unix domain] socket.

=over

=item since: 1.99_17

=back





=head3 C<APR::FILETYPE_UNKFILE>

a file is of some other unknown type or the type cannot be determined.

=over

=item since: 1.99_17

=back










=head2 C<:finfo>

  use APR::Const -compile => qw(:finfo);

The C<:finfo> group is used by
C<L<stat()|docs::2.0::api::APR::Finfo/C_stat_>> and
C<L<$finfo-E<gt>valid|docs::2.0::api::APR::Finfo/C_valid_>>.




=head3 C<APR::FINFO_ATIME>

Access Time

=over

=item since: 1.99_12

=back





=head3 C<APR::FINFO_CSIZE>

Storage size consumed by the file

=over

=item since: 1.99_12

=back





=head3 C<APR::FINFO_CTIME>

Creation Time

=over

=item since: 1.99_12

=back





=head3 C<APR::FINFO_DEV>

Device

=over

=item since: 1.99_12

=back





=head3 C<APR::FINFO_DIRENT>

an atomic unix apr_dir_read()

=over

=item since: 1.99_12

=back





=head3 C<APR::FINFO_GPROT>

Group protection bits

=over

=item since: 1.99_12

=back





=head3 C<APR::FINFO_GROUP>

Group id

=over

=item since: 1.99_12

=back





=head3 C<APR::FINFO_ICASE>

whether device is case insensitive

=over

=item since: 1.99_12

=back





=head3 C<APR::FINFO_IDENT>

device and inode

=over

=item since: 1.99_12

=back





=head3 C<APR::FINFO_INODE>

Inode

=over

=item since: 1.99_12

=back





=head3 C<APR::FINFO_LINK>

Stat the link not the file itself if it is a link

=over

=item since: 1.99_12

=back





=head3 C<APR::FINFO_MIN>

type, mtime, ctime, atime, size

=over

=item since: 1.99_12

=back





=head3 C<APR::FINFO_MTIME>

Modification Time

=over

=item since: 1.99_12

=back





=head3 C<APR::FINFO_NAME>

name in proper case

=over

=item since: 1.99_12

=back





=head3 C<APR::FINFO_NLINK>

Number of links

=over

=item since: 1.99_12

=back





=head3 C<APR::FINFO_NORM>

All fields provided by an atomic unix apr_stat()

=over

=item since: 1.99_12

=back





=head3 C<APR::FINFO_OWNER>

user and group

=over

=item since: 1.99_12

=back





=head3 C<APR::FINFO_PROT>

all protections

=over

=item since: 1.99_12

=back





=head3 C<APR::FINFO_SIZE>

Size of the file

=over

=item since: 1.99_12

=back





=head3 C<APR::FINFO_TYPE>

Type

=over

=item since: 1.99_12

=back





=head3 C<APR::FINFO_UPROT>

User protection bits

=over

=item since: 1.99_12

=back





=head3 C<APR::FINFO_USER>

User id

=over

=item since: 1.99_12

=back





=head3 C<APR::FINFO_WPROT>

World protection bits

=over

=item since: 1.99_12

=back









=head2 C<:flock>

  use APR::Const -compile => qw(:flock);

The C<:flock> group is for XXX constants.




=head3 C<APR::FLOCK_EXCLUSIVE>

=over

=item since: 1.99_12

=back





=head3 C<APR::FLOCK_NONBLOCK>

=over

=item since: 1.99_12

=back





=head3 C<APR::FLOCK_SHARED>

=over

=item since: 1.99_12

=back





=head3 C<APR::FLOCK_TYPEMASK>

=over

=item since: 1.99_12

=back





=head2 C<:hook>

  use APR::Const -compile => qw(:hook);

The C<:hook> group is for XXX constants.




=head3 C<APR::HOOK_FIRST>

=over

=item since: 1.99_12

=back





=head3 C<APR::HOOK_LAST>

=over

=item since: 1.99_12

=back





=head3 C<APR::HOOK_MIDDLE>

=over

=item since: 1.99_12

=back





=head3 C<APR::HOOK_REALLY_FIRST>

=over

=item since: 1.99_12

=back





=head3 C<APR::HOOK_REALLY_LAST>

=over

=item since: 1.99_12

=back





=head2 C<:limit>

  use APR::Const -compile => qw(:limit);

The C<:limit> group is for XXX constants.




=head3 C<APR::LIMIT_CPU>

=over

=item since: 1.99_12

=back





=head3 C<APR::LIMIT_MEM>

=over

=item since: 1.99_12

=back





=head3 C<APR::LIMIT_NOFILE>

=over

=item since: 1.99_12

=back





=head3 C<APR::LIMIT_NPROC>

=over

=item since: 1.99_12

=back





=head2 C<:lockmech>

  use APR::Const -compile => qw(:lockmech);

The C<:lockmech> group is for XXX constants.




=head3 C<APR::LOCK_DEFAULT>

=over

=item since: 1.99_12

=back





=head3 C<APR::LOCK_FCNTL>

=over

=item since: 1.99_12

=back





=head3 C<APR::LOCK_FLOCK>

=over

=item since: 1.99_12

=back





=head3 C<APR::LOCK_POSIXSEM>

=over

=item since: 1.99_12

=back





=head3 C<APR::LOCK_PROC_PTHREAD>

=over

=item since: 1.99_12

=back





=head3 C<APR::LOCK_SYSVSEM>

=over

=item since: 1.99_12

=back





=head2 C<:poll>

  use APR::Const -compile => qw(:poll);

The C<:poll> group is used by
C<L<poll|docs::2.0::api::APR::Socket/C_poll_>>.




=head3 C<APR::POLLERR>

=over

=item since: 1.99_12

=back

Pending error




=head3 C<APR::POLLHUP>

=over

=item since: 1.99_12

=back

Hangup occurred




=head3 C<APR::POLLIN>

=over

=item since: 1.99_12

=back

Can read without blocking




=head3 C<APR::POLLNVAL>

=over

=item since: 1.99_12

=back

Descriptior invalid




=head3 C<APR::POLLOUT>

=over

=item since: 1.99_12

=back

Can write without blocking





=head3 C<APR::POLLPRI>

=over

=item since: 1.99_12

=back

Priority data available













=head2 C<:read_type>

  use APR::Const -compile => qw(:read_type);

The C<:read_type> group is for IO constants.




=head3 C<APR::BLOCK_READ>

=over

=item since: 1.99_12

=back

the read function blocks





=head3 C<APR::NONBLOCK_READ>

=over

=item since: 1.99_12

=back


the read function does not block










=head2 C<:shutdown_how>

  use APR::Const -compile => qw(:shutdown_how);

The C<:shutdown_how> group is for XXX constants.




=head3 C<APR::SHUTDOWN_READ>

=over

=item since: 1.99_12

=back





=head3 C<APR::SHUTDOWN_READWRITE>

=over

=item since: 1.99_12

=back





=head3 C<APR::SHUTDOWN_WRITE>

=over

=item since: 1.99_12

=back





=head2 C<:socket>

  use APR::Const -compile => qw(:socket);

The C<:socket> group is for the
C<L<APR::Socket|docs::2.0::api::APR::Socket>> object constants, in
methods C<L<opt_get|docs::2.0::api::APR::Socket/C_opt_get_>> and
C<L<opt_set|docs::2.0::api::APR::Socket/C_opt_set_>>.

The following section discusses in detail each of the C<:socket>
constants.




=head3 C<APR::SO_DEBUG>

Possible values:

XXX

=over

=item since: 1.99_12

=back

Turns on debugging information




=head3 C<APR::SO_DISCONNECTED>

Queries the disconnected state of the socket.  (Currently only used on
Windows)

Possible values:

XXX

=over

=item since: 1.99_12

=back






=head3 C<APR::SO_KEEPALIVE>

Keeps connections active

Possible values:

XXX

=over

=item since: 1.99_12

=back








=head3 C<APR::SO_LINGER>

Lingers on close if data is present

=over

=item since: 1.99_12

=back







=head3 C<APR::SO_NONBLOCK>

Turns blocking IO mode on/off for socket.

Possible values:

  1 nonblocking
  0 blocking

For example, to set a socket to a blocking IO mode:

  use APR::Socket ();
  use APR::Const    -compile => qw(SO_NONBLOCK);
  ...
  if ($socket->opt_get(APR::SO_NONBLOCK)) {
      $socket->opt_set(APR::SO_NONBLOCK => 0);
  }

You don't have to query for this option, before setting it. It was
done for the demonstration purpose.

=over

=item since: 1.99_12

=back









=head3 C<APR::SO_RCVBUF>

Controls the C<ReceiveBufferSize> setting

Possible values:

XXX

=over

=item since: 1.99_12

=back








=head3 C<APR::SO_REUSEADDR>

The rules used in validating addresses supplied to bind should allow
reuse of local addresses.

Possible values:

XXX

=over

=item since: 1.99_12

=back








=head3 C<APR::SO_SNDBUF>

Controls the C<SendBufferSize> setting

Possible values:

XXX

=over

=item since: 1.99_12

=back





=head2 C<:status>

  use APR::Const -compile => qw(:status);

The C<:status> group is for the API that return status code, or set
the error variable XXXXXX.

The following section discusses in detail each of the available
C<:status> constants.




=head3 C<APR::TIMEUP>

The operation did not finish before the timeout.

=over

=item since: 1.99_14

=back














=head2 C<:table>

  use APR::Const -compile => qw(:table);

The C<:table> group is for C<overlap()> and C<compress()> constants.
See C<L<APR::Table|docs::2.0::api::APR::Table>> for details.




=head3 C<APR::OVERLAP_TABLES_MERGE>

=over

=item since: 1.99_12

=back

See C<L<APR::Table::compress|docs::2.0::api::APR::Table/C_compress_>>
and C<L<APR::Table::overlap|docs::2.0::api::APR::Table/C_overlap_>>.





=head3 C<APR::OVERLAP_TABLES_SET>

=over

=item since: 1.99_12

=back

See C<L<APR::Table::compress|docs::2.0::api::APR::Table/C_compress_>>
and C<L<APR::Table::overlap|docs::2.0::api::APR::Table/C_overlap_>>.





=head2 C<:uri>

  use APR::Const -compile => qw(:uri);

The C<:uri> group of constants is for manipulating URIs.




=head3 C<APR::URI_ACAP_DEFAULT_PORT>

=over

=item since: 1.99_12

=back





=head3 C<APR::URI_FTP_DEFAULT_PORT>

=over

=item since: 1.99_12

=back





=head3 C<APR::URI_GOPHER_DEFAULT_PORT>

=over

=item since: 1.99_12

=back





=head3 C<APR::URI_HTTPS_DEFAULT_PORT>

=over

=item since: 1.99_12

=back






=head3 C<APR::URI_HTTP_DEFAULT_PORT>

=over

=item since: 1.99_12

=back






=head3 C<APR::URI_IMAP_DEFAULT_PORT>

=over

=item since: 1.99_12

=back





=head3 C<APR::URI_LDAP_DEFAULT_PORT>

=over

=item since: 1.99_12

=back






=head3 C<APR::URI_NFS_DEFAULT_PORT>

=over

=item since: 1.99_12

=back






=head3 C<APR::URI_NNTP_DEFAULT_PORT>

=over

=item since: 1.99_12

=back






=head3 C<APR::URI_POP_DEFAULT_PORT>

=over

=item since: 1.99_12

=back






=head3 C<APR::URI_PROSPERO_DEFAULT_PORT>

=over

=item since: 1.99_12

=back






=head3 C<APR::URI_RTSP_DEFAULT_PORT>

=over

=item since: 1.99_12

=back







=head3 C<APR::URI_SIP_DEFAULT_PORT>

=over

=item since: 1.99_12

=back









=head3 C<APR::URI_SNEWS_DEFAULT_PORT>

=over

=item since: 1.99_12

=back





=head3 C<APR::URI_SSH_DEFAULT_PORT>

=over

=item since: 1.99_12

=back





=head3 C<APR::URI_TELNET_DEFAULT_PORT>

=over

=item since: 1.99_12

=back







=head3 C<APR::URI_TIP_DEFAULT_PORT>

=over

=item since: 1.99_12

=back








=head3 C<APR::URI_UNP_OMITPASSWORD>

=over

=item since: 1.99_12

=back

See C<L<APR::URI::unparse|docs::2.0::api::APR::URI/C_unparse_>>.








=head3 C<APR::URI_UNP_OMITPATHINFO>

=over

=item since: 1.99_12

=back

See C<L<APR::URI::unparse|docs::2.0::api::APR::URI/C_unparse_>>.








=head3 C<APR::URI_UNP_OMITQUERY>

=over

=item since: 1.99_12

=back

See C<L<APR::URI::unparse|docs::2.0::api::APR::URI/C_unparse_>>.








=head3 C<APR::URI_UNP_OMITSITEPART>

=over

=item since: 1.99_12

=back

See C<L<APR::URI::unparse|docs::2.0::api::APR::URI/C_unparse_>>.







=head3 C<APR::URI_UNP_OMITUSER>

=over

=item since: 1.99_12

=back

See C<L<APR::URI::unparse|docs::2.0::api::APR::URI/C_unparse_>>.





=head3 C<APR::URI_UNP_OMITUSERINFO>

=over

=item since: 1.99_12

=back








=head3 C<APR::URI_UNP_REVEALPASSWORD>

=over

=item since: 1.99_12

=back

See C<L<APR::URI::unparse|docs::2.0::api::APR::URI/C_unparse_>>.







=head3 C<APR::URI_WAIS_DEFAULT_PORT>

=over

=item since: 1.99_12

=back



=head2 Other Constants


=head3 C<APR::PerlIO::PERLIO_LAYERS_ARE_ENABLED>

=over

=item since: 1.99_10

=back

See C<L<APR::PerlIO::Constants|docs::2.0::api::APR::PerlIO/Constants>>)





=head1 See Also

L<mod_perl 2.0 documentation|docs::2.0::index>.




=head1 Copyright

mod_perl 2.0 and its core modules are copyrighted under
The Apache Software License, Version 2.0.




=head1 Authors

L<The mod_perl development team and numerous
contributors|about::contributors::people>.

=cut
